# Licensed under a 3-clause BSD style license - see LICENSE.rst

"""
SOLARSYSTEM.IMCCE.MIRIADE
-------------------------

:author: Michael Mommert (mommermiscience@gmail.com)
"""

from ....imcce import Miriade, MiriadeClass


__all__ = ["Miriade", "MiriadeClass"]
